@@ -1,6 +1,8 @@
 # !/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import xlwt
+import csv
 import pandas as pd
 from functools import partial
 import json
@@ -37,11 +39,29 @@ class DataApi:
             if result['code'] != 0:
                 raise Exception(result['msg'])
             data = result['data']
-            columns = data['fields']
-            items = data['items']
-            return pd.DataFrame(items, columns=columns), data['info']
+            return data
         else:
-            return pd.DataFrame(), None
+            return None
+
+    def export(self, file_path, file_type, api_name, fields=[], **kwargs):
+        data = self.query(api_name, fields, **kwargs)
+        alias_fields = data['alias_fields']
+        items = data['items']
+        df = pd.DataFrame(columns=alias_fields, data=items)
+        if file_type == 'xls':
+            df.to_excel(file_path)
+        elif file_type == 'csv':
+            df.to_csv(file_path, sep='\t')
+        elif file_type == 'html':
+            with open(file_path, 'w', encoding='utf-8') as f:
+                f.write("<html>" + '\n')
+                f.write("<meta charset='utf-8'>" + '\n')
+                f.write(
+                    "<link href='https://cdn.jsdelivr.net/npm/bootstrap@3.3.7/dist/css/bootstrap.min.css' rel='stylesheet'>" + '\n')
+                f.write(df.to_html())
+                f.write("<html>")
+        elif file_type == 'json':
+            df.to_json(file_path)
 
     def __getattr__(self, name):
         return partial(self.query, name)
